utils::globalVariables(c("evas_list",
                         "verbose",
                         "menu",
                         "setNames",
                         "error.ignore"))
